summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/folder.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/folder.cpp
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/folder.cpp')
-rw-r--r--umbrello/umbrello/folder.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/umbrello/umbrello/folder.cpp b/umbrello/umbrello/folder.cpp
index c3f97dc4..2ba73694 100644
--- a/umbrello/umbrello/folder.cpp
+++ b/umbrello/umbrello/folder.cpp
@@ -157,8 +157,8 @@ void UMLFolder::removeAllViews() {
UMLView *v = NULL;
for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit) {
// TODO ------------------ check this code - bad: calling back to UMLDoc::removeView()
- v->removeAllAssociations(); // note : It may not be apparent, but when we remove all associations
- // from a view, it also causes any UMLAssociations that lack parent
+ v->removeAllAssociations(); // note : It may not be aptqparent, but when we remove all associations
+ // from a view, it also causes any UMLAssociations that lack tqparent
// association widgets (but once had them) to remove themselves from
// this document.
UMLApp::app()->getDocument()->removeView(v, false);
@@ -223,7 +223,7 @@ void UMLFolder::saveToXMI(TQDomDocument& qDoc, TQDomElement& qElement) {
kError() << "UMLFolder::saveToXMI(" << m_folderFile << "): "
<< "cannot create file, contents will be saved in main model file"
<< endl;
- m_folderFile = TQString::null;
+ m_folderFile = TQString();
save(qDoc, qElement);
return;
}
@@ -248,8 +248,8 @@ void UMLFolder::saveToXMI(TQDomDocument& qDoc, TQDomElement& qElement) {
folderRoot.setAttribute("name", m_Name);
folderRoot.setAttribute("filename", m_folderFile);
folderRoot.setAttribute("mainModel", umldoc->URL().fileName());
- folderRoot.setAttribute("parentId", ID2STR(m_pUMLPackage->getID()));
- folderRoot.setAttribute("parent", m_pUMLPackage->getFullyQualifiedName("::", true));
+ folderRoot.setAttribute("tqparentId", ID2STR(m_pUMLPackage->getID()));
+ folderRoot.setAttribute("tqparent", m_pUMLPackage->getFullyQualifiedName("::", true));
saveContents(folderDoc, folderRoot);
folderDoc.appendChild(folderRoot);
TQTextStream stream(&file);
@@ -286,11 +286,11 @@ bool UMLFolder::loadDiagramsFromXMI(TQDomNode& diagrams) {
bool UMLFolder::loadFolderFile(const TQString& path) {
TQFile file(path);
if (!file.exists()) {
- KMessageBox::error(0, i18n("The folderfile %1 does not exist.").arg(path), i18n("Load Error"));
+ KMessageBox::error(0, i18n("The folderfile %1 does not exist.").tqarg(path), i18n("Load Error"));
return false;
}
if (!file.open(IO_ReadOnly)) {
- KMessageBox::error(0, i18n("The folderfile %1 cannot be opened.").arg(path), i18n("Load Error"));
+ KMessageBox::error(0, i18n("The folderfile %1 cannot be opened.").tqarg(path), i18n("Load Error"));
return false;
}
TQTextStream stream(&file);